@@ -110,7 +110,7 @@ pub fn generate_closure_template(
 
         let future = async move {
             future_inner.await;
-            context.finishe_task(None).await;
+            context.finish_task(None).await;
         };
         create_delay_task_handler(async_spawn(future))
     }
